
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#include <config.h>

#include "gucharmap.h"
#include "gucharmap-type-builtins.h"
/* enumerations from "/usr/src/ports/gucharmap/gucharmap-10.0.3-1.x86_64/src/gucharmap-10.0.3/gucharmap/gucharmap-charmap.h" */

#include "/usr/src/ports/gucharmap/gucharmap-10.0.3-1.x86_64/src/gucharmap-10.0.3/gucharmap/gucharmap-charmap.h"
GType
gucharmap_charmap_page_type_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;
 
  if (g_once_init_enter (&g_define_type_id__volatile)) {
    static const GEnumValue values[] = {
      { GUCHARMAP_CHARMAP_PAGE_CHARTABLE, "GUCHARMAP_CHARMAP_PAGE_CHARTABLE", "chartable" },
      { GUCHARMAP_CHARMAP_PAGE_DETAILS, "GUCHARMAP_CHARMAP_PAGE_DETAILS", "details" },
      { 0, NULL, NULL }
    };
    GType g_define_type_id = \
       g_enum_register_static (/* g_intern_static_string */ ("GucharmapCharmapPageType"), values);
      
    g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
  }
    
  return g_define_type_id__volatile;
}
/* enumerations from "/usr/src/ports/gucharmap/gucharmap-10.0.3-1.x86_64/src/gucharmap-10.0.3/gucharmap/gucharmap-unicode-info.h" */

#include "/usr/src/ports/gucharmap/gucharmap-10.0.3-1.x86_64/src/gucharmap-10.0.3/gucharmap/gucharmap-unicode-info.h"
GType
gucharmap_unicode_version_get_type (void)
{
  static volatile gsize g_define_type_id__volatile = 0;
 
  if (g_once_init_enter (&g_define_type_id__volatile)) {
    static const GEnumValue values[] = {
      { GUCHARMAP_UNICODE_VERSION_UNASSIGNED, "GUCHARMAP_UNICODE_VERSION_UNASSIGNED", "unassigned" },
      { GUCHARMAP_UNICODE_VERSION_1_1, "GUCHARMAP_UNICODE_VERSION_1_1", "1-1" },
      { GUCHARMAP_UNICODE_VERSION_2_0, "GUCHARMAP_UNICODE_VERSION_2_0", "2-0" },
      { GUCHARMAP_UNICODE_VERSION_2_1, "GUCHARMAP_UNICODE_VERSION_2_1", "2-1" },
      { GUCHARMAP_UNICODE_VERSION_3_0, "GUCHARMAP_UNICODE_VERSION_3_0", "3-0" },
      { GUCHARMAP_UNICODE_VERSION_3_1, "GUCHARMAP_UNICODE_VERSION_3_1", "3-1" },
      { GUCHARMAP_UNICODE_VERSION_3_2, "GUCHARMAP_UNICODE_VERSION_3_2", "3-2" },
      { GUCHARMAP_UNICODE_VERSION_4_0, "GUCHARMAP_UNICODE_VERSION_4_0", "4-0" },
      { GUCHARMAP_UNICODE_VERSION_4_1, "GUCHARMAP_UNICODE_VERSION_4_1", "4-1" },
      { GUCHARMAP_UNICODE_VERSION_5_0, "GUCHARMAP_UNICODE_VERSION_5_0", "5-0" },
      { GUCHARMAP_UNICODE_VERSION_5_1, "GUCHARMAP_UNICODE_VERSION_5_1", "5-1" },
      { GUCHARMAP_UNICODE_VERSION_5_2, "GUCHARMAP_UNICODE_VERSION_5_2", "5-2" },
      { GUCHARMAP_UNICODE_VERSION_6_0, "GUCHARMAP_UNICODE_VERSION_6_0", "6-0" },
      { GUCHARMAP_UNICODE_VERSION_6_1, "GUCHARMAP_UNICODE_VERSION_6_1", "6-1" },
      { GUCHARMAP_UNICODE_VERSION_6_2, "GUCHARMAP_UNICODE_VERSION_6_2", "6-2" },
      { GUCHARMAP_UNICODE_VERSION_6_3, "GUCHARMAP_UNICODE_VERSION_6_3", "6-3" },
      { GUCHARMAP_UNICODE_VERSION_7_0, "GUCHARMAP_UNICODE_VERSION_7_0", "7-0" },
      { GUCHARMAP_UNICODE_VERSION_8_0, "GUCHARMAP_UNICODE_VERSION_8_0", "8-0" },
      { GUCHARMAP_UNICODE_VERSION_9_0, "GUCHARMAP_UNICODE_VERSION_9_0", "9-0" },
      { GUCHARMAP_UNICODE_VERSION_10_0, "GUCHARMAP_UNICODE_VERSION_10_0", "10-0" },
      { GUCHARMAP_UNICODE_VERSION_LATEST, "GUCHARMAP_UNICODE_VERSION_LATEST", "latest" },
      { 0, NULL, NULL }
    };
    GType g_define_type_id = \
       g_enum_register_static (/* g_intern_static_string */ ("GucharmapUnicodeVersion"), values);
      
    g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
  }
    
  return g_define_type_id__volatile;
}


/* Generated data ends here */

